import { Component, h } from '@stencil/core';
import { format } from 'date-fns';
import orders from '../../data/orders';
export class LlamaFeed {
  renderStatusClass(orderStatus) {
    let classes = 'h-8 w-8 rounded-full flex items-center justify-center ring-8 ring-white';
    switch (orderStatus) {
      case 'accepted':
      case 'accepted_for_bidding':
      case 'filled':
        classes += ' bg-green-400';
        break;
      case 'new':
      case 'calculated':
      case 'partially_filled':
      case 'pending_cancel':
      case 'pending_new':
      case 'pending_replace':
      case 'replaced':
        classes += ' bg-yellow-400';
        break;
      case 'canceled':
      case 'done_for_day':
      case 'expired':
      case 'rejected':
      case 'stopped':
      case 'suspended':
        classes += ' bg-red-400';
        break;
      default:
        classes += ' bg-gray-400';
    }
    return classes;
  }
  // TODO Add comment
  renderStatusIcon(orderStatus) {
    // Green, yellow, red
    // yellow
    // X
    // <svg xmlns="http://www.w3.org/2000/svg" className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
    //   <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2"
    //         d="M10 14l2-2m0 0l2-2m-2 2l-2-2m2 2l2 2m7-2a9 9 0 11-18 0 9 9 0 0118 0z" />
    // </svg>
    switch (orderStatus) {
      case 'accepted':
      case 'filled':
        return (h("svg", { class: "h-5 w-5 text-white", xmlns: "http://www.w3.org/2000/svg", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" },
          h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" })));
      case 'expired':
        return (h("svg", { class: "h-5 w-5 text-white", xmlns: "http://www.w3.org/2000/svg", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" },
          h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M10 14l2-2m0 0l2-2m-2 2l-2-2m2 2l2 2m7-2a9 9 0 11-18 0 9 9 0 0118 0z" })));
    }
    switch (orderStatus) {
      case 'accepted':
      case 'accepted_for_bidding':
      case 'filled':
        return (h("svg", { class: "h-5 w-5 text-white", xmlns: "http://www.w3.org/2000/svg", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" },
          h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" })));
      case 'new':
      case 'calculated':
      case 'partially_filled':
      case 'pending_cancel':
      case 'pending_new':
      case 'pending_replace':
      case 'replaced':
        return (h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-6 w-6", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" },
          h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": 2, d: "M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" })));
      case 'canceled':
      case 'done_for_day':
      case 'expired':
      case 'rejected':
      case 'stopped':
      case 'suspended':
        return (h("svg", { class: "h-5 w-5 text-white", xmlns: "http://www.w3.org/2000/svg", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" },
          h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M10 14l2-2m0 0l2-2m-2 2l-2-2m2 2l2 2m7-2a9 9 0 11-18 0 9 9 0 0118 0z" })));
      default:
        return (h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-6 w-6", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" },
          h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M13 16h-1v-4h-1m1-4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" })));
    }
  }
  render() {
    return (h("div", { class: "bg-white overflow-hidden shadow rounded-lg" },
      h("div", { class: "flex px-4 py-5 sm:px-6" }, "Feed"),
      h("div", { class: "bg-gray-50 px-4 py-5 sm:p-6 space-y-4" },
        h("ul", { class: "-mb-8" }, orders.map((order, index) => (h("li", null,
          h("div", { class: "relative pb-8" },
            index < orders.length - 1 && h("span", { class: "absolute top-4 left-4 -ml-px h-full w-0.5 bg-gray-200", "aria-hidden": "true" }),
            h("div", { class: "relative flex space-x-3" },
              h("div", null,
                h("span", { class: this.renderStatusClass(order.status) }, this.renderStatusIcon(order.status))),
              h("div", { class: "min-w-0 flex-1 pt-1.5 flex justify-between space-x-4" },
                h("div", null,
                  h("p", { class: "text-sm text-gray-500" },
                    h("span", { class: "capitalize" }, order.type),
                    " ",
                    order.side,
                    " for ",
                    order.qty,
                    " shares of ",
                    h("b", null, order.symbol))),
                h("div", { class: "text-right text-sm whitespace-nowrap text-gray-500" },
                  h("time", { dateTime: order.created_at }, format(new Date(order.created_at), 'Pp')))))))))))));
  }
  static get is() { return "llama-feed"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["llama-feed.css"]
  }; }
  static get styleUrls() { return {
    "$": ["llama-feed.css"]
  }; }
}
