import { Component, h, State } from '@stencil/core';
import { alpaca, alpacaData, percentChange, serialize } from '../../utils/utils';
export class LlamaWatchlists {
  constructor() {
    this.openWatchlists = new Set();
    this.symbolTrades = new Map();
    this.symbolBars = new Map();
    this.myElement = [];
  }
  componentWillLoad() {
    return new Promise(async (resolve) => {
      const response = await alpaca('/v2/watchlists');
      const watchlists = await response.json();
      this.watchlists = await Promise.all(watchlists.map(async (watchlist) => {
        const response = await alpaca(`/v2/watchlists/${watchlist.id}`);
        return response.json();
      }));
      resolve();
    });
  }
  onWatchlistClick(id) {
    const set = new Set(this.openWatchlists);
    set.has(id) ? set.delete(id) : set.add(id);
    // When opening a watchlist, get latest trade for assets
    const watchlist = this.watchlists.find(x => x.id === id);
    Promise.all(watchlist.assets.map(async (asset) => {
      const response = await alpacaData(`/v1/last/stocks/${asset.symbol}`);
      return response.json();
    })).then(data => {
      data.forEach(lastTrade => {
        const map = new Map(this.symbolTrades);
        // @ts-ignore
        this.symbolTrades = map.set(lastTrade.symbol, lastTrade.last.price);
      });
    });
    // When opening a watchlist, get historical data for assets
    const symbols = watchlist.assets.map(asset => asset.symbol);
    const start = new Date();
    start.setHours(8);
    const parameters = {
      symbols: symbols.join(','),
      start: start.toISOString(),
      end: new Date().toISOString(),
    };
    alpacaData(`/v1/bars/5Min?${serialize(parameters)}`).then(async (response) => {
      const json = await response.json();
      symbols.forEach(symbol => {
        const map = new Map(this.symbolBars);
        this.symbolBars = map.set(symbol, json[symbol]);
      });
    });
    this.openWatchlists = set;
  }
  chevronDown() {
    return (h("svg", { xmlns: "http://www.w3.org/2000/svg", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" },
      h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M19 9l-7 7-7-7" })));
  }
  chevronUp() {
    return (h("svg", { xmlns: "http://www.w3.org/2000/svg", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor" },
      h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "2", d: "M5 15l7-7 7 7" })));
  }
  render() {
    return (h("div", { class: "bg-white overflow-hidden shadow rounded-lg" },
      h("div", { class: "flex px-4 py-5 sm:px-6" }, "Watchlists"),
      h("div", { class: "bg-gray-50 px-4 py-5 sm:p-6 space-y-4" }, this.watchlists.map((watchlist, i) => (h("div", { class: "bg-white overflow-hidden shadow rounded-lg divide-y divide-gray-200" },
        h("div", { class: "flex px-4 py-5 sm:px-6 cursor-pointer", onClick: () => this.onWatchlistClick(watchlist.id) },
          h("div", { class: "flex-1" }, watchlist.name),
          h("div", { class: "flex-shrink" },
            h("div", { class: "bg-black bg-opacity-10 h-8 w-8 rounded-full flex items-center justify-center" }, this.openWatchlists.has(watchlist.id) ? this.chevronUp() : this.chevronDown()))),
        h("div", { ref: el => this.myElement.push(el), class: "transition-all duration-700", style: { 'max-height': this.openWatchlists.has(watchlist.id) ? `${this.myElement[i].scrollHeight}px` : '0' } },
          h("ul", { class: "divide-y divide-gray-200" }, watchlist.assets.map(asset => (h("li", null,
            h("div", { class: "flex items-center px-4 py-4 sm:px-6" },
              h("div", { class: "flex-1" }, asset.symbol),
              h("div", { class: "flex-shrink text-right" },
                h("p", { class: "text-sm" }, new Intl.NumberFormat('en-US', { style: 'currency', currency: 'USD' }).format(this.symbolTrades.get(asset.symbol))),
                this.symbolTrades.get(asset.symbol) && this.symbolBars.get(asset.symbol) && (h("p", { class: "text-sm text-red-500" },
                  percentChange(this.symbolTrades.get(asset.symbol), this.symbolBars.get(asset.symbol)[0].c),
                  "%")))))))))))))));
  }
  static get is() { return "llama-watchlists"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["llama-watchlists.css"]
  }; }
  static get styleUrls() { return {
    "$": ["llama-watchlists.css"]
  }; }
  static get states() { return {
    "watchlists": {},
    "openWatchlists": {},
    "symbolTrades": {},
    "symbolBars": {},
    "myElement": {}
  }; }
}
